# mypy-boto3-greengrass

Mypy-friendly auto-generated type annotations for `boto3 greengrass 1.10.39` service.
More information can be found [here](https://github.com/vemel/mypy_boto3).

- [mypy-boto3-greengrass](#mypy-boto3-greengrass)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `greengrass` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-greengrass]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking.

```python
import boto3

from mypy_boto3 import greengrass
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_greengrass as greengrass

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("greengrass")
client: greengrass.GreengrassClient = boto3.client("greengrass")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: greengrass.GreengrassClient = session.client("greengrass")


# Paginators need type annotation on creation
list_bulk_deployment_detailed_reports_paginator: greengrass.ListBulkDeploymentDetailedReportsPaginator = client.get_paginator("list_bulk_deployment_detailed_reports")
list_bulk_deployments_paginator: greengrass.ListBulkDeploymentsPaginator = client.get_paginator("list_bulk_deployments")
list_connector_definition_versions_paginator: greengrass.ListConnectorDefinitionVersionsPaginator = client.get_paginator("list_connector_definition_versions")
list_connector_definitions_paginator: greengrass.ListConnectorDefinitionsPaginator = client.get_paginator("list_connector_definitions")
list_core_definition_versions_paginator: greengrass.ListCoreDefinitionVersionsPaginator = client.get_paginator("list_core_definition_versions")
list_core_definitions_paginator: greengrass.ListCoreDefinitionsPaginator = client.get_paginator("list_core_definitions")
list_deployments_paginator: greengrass.ListDeploymentsPaginator = client.get_paginator("list_deployments")
list_device_definition_versions_paginator: greengrass.ListDeviceDefinitionVersionsPaginator = client.get_paginator("list_device_definition_versions")
list_device_definitions_paginator: greengrass.ListDeviceDefinitionsPaginator = client.get_paginator("list_device_definitions")
list_function_definition_versions_paginator: greengrass.ListFunctionDefinitionVersionsPaginator = client.get_paginator("list_function_definition_versions")
list_function_definitions_paginator: greengrass.ListFunctionDefinitionsPaginator = client.get_paginator("list_function_definitions")
list_group_versions_paginator: greengrass.ListGroupVersionsPaginator = client.get_paginator("list_group_versions")
list_groups_paginator: greengrass.ListGroupsPaginator = client.get_paginator("list_groups")
list_logger_definition_versions_paginator: greengrass.ListLoggerDefinitionVersionsPaginator = client.get_paginator("list_logger_definition_versions")
list_logger_definitions_paginator: greengrass.ListLoggerDefinitionsPaginator = client.get_paginator("list_logger_definitions")
list_resource_definition_versions_paginator: greengrass.ListResourceDefinitionVersionsPaginator = client.get_paginator("list_resource_definition_versions")
list_resource_definitions_paginator: greengrass.ListResourceDefinitionsPaginator = client.get_paginator("list_resource_definitions")
list_subscription_definition_versions_paginator: greengrass.ListSubscriptionDefinitionVersionsPaginator = client.get_paginator("list_subscription_definition_versions")
list_subscription_definitions_paginator: greengrass.ListSubscriptionDefinitionsPaginator = client.get_paginator("list_subscription_definitions")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- Latest version of `boto3` is used.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from latest documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Code is processed by [black](https://github.com/psf/black) for readability.